# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-beta
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import skil_client
from skil_client.models.download_output_file_request import DownloadOutputFileRequest  # noqa: E501
from skil_client.rest import ApiException


class TestDownloadOutputFileRequest(unittest.TestCase):
    """DownloadOutputFileRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDownloadOutputFileRequest(self):
        """Test DownloadOutputFileRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = skil_client.models.download_output_file_request.DownloadOutputFileRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
