# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-beta
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ModelHistoryEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created': 'int',
        'model_history_id': 'str',
        'model_name': 'str',
        'model_labels': 'str'
    }

    attribute_map = {
        'created': 'created',
        'model_history_id': 'modelHistoryId',
        'model_name': 'modelName',
        'model_labels': 'modelLabels'
    }

    def __init__(self, created=None, model_history_id=None, model_name=None, model_labels=None):  # noqa: E501
        """ModelHistoryEntity - a model defined in Swagger"""  # noqa: E501

        self._created = None
        self._model_history_id = None
        self._model_name = None
        self._model_labels = None
        self.discriminator = None

        if created is not None:
            self.created = created
        if model_history_id is not None:
            self.model_history_id = model_history_id
        if model_name is not None:
            self.model_name = model_name
        if model_labels is not None:
            self.model_labels = model_labels

    @property
    def created(self):
        """Gets the created of this ModelHistoryEntity.  # noqa: E501

        When the model history / workspace was created  # noqa: E501

        :return: The created of this ModelHistoryEntity.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ModelHistoryEntity.

        When the model history / workspace was created  # noqa: E501

        :param created: The created of this ModelHistoryEntity.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def model_history_id(self):
        """Gets the model_history_id of this ModelHistoryEntity.  # noqa: E501

        The GUID of the model history / workspace  # noqa: E501

        :return: The model_history_id of this ModelHistoryEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_history_id

    @model_history_id.setter
    def model_history_id(self, model_history_id):
        """Sets the model_history_id of this ModelHistoryEntity.

        The GUID of the model history / workspace  # noqa: E501

        :param model_history_id: The model_history_id of this ModelHistoryEntity.  # noqa: E501
        :type: str
        """

        self._model_history_id = model_history_id

    @property
    def model_name(self):
        """Gets the model_name of this ModelHistoryEntity.  # noqa: E501

        Name of the model history / workspace  # noqa: E501

        :return: The model_name of this ModelHistoryEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this ModelHistoryEntity.

        Name of the model history / workspace  # noqa: E501

        :param model_name: The model_name of this ModelHistoryEntity.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def model_labels(self):
        """Gets the model_labels of this ModelHistoryEntity.  # noqa: E501

        Model history / workspace labels  # noqa: E501

        :return: The model_labels of this ModelHistoryEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_labels

    @model_labels.setter
    def model_labels(self, model_labels):
        """Sets the model_labels of this ModelHistoryEntity.

        Model history / workspace labels  # noqa: E501

        :param model_labels: The model_labels of this ModelHistoryEntity.  # noqa: E501
        :type: str
        """

        self._model_labels = model_labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelHistoryEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
